api.reports.v1.test_helpers.schedule package — Argus-Toolbelt 1.0 documentation

# api.reports.v1.test_helpers.schedule package

## Submodules

## api.reports.v1.test_helpers.schedule.add module

`api.reports.v1.test_helpers.schedule.add.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule/w+, respond with HTTP 403

`api.reports.v1.test_helpers.schedule.add.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule/w+, respond with HTTP 404

`api.reports.v1.test_helpers.schedule.add.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule/w+, respond with HTTP 200

`api.reports.v1.test_helpers.schedule.add.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule/w+, respond with HTTP 401

## api.reports.v1.test_helpers.schedule.delete module

`api.reports.v1.test_helpers.schedule.delete.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule/w+, respond with HTTP 403

`api.reports.v1.test_helpers.schedule.delete.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule/w+, respond with HTTP 404

`api.reports.v1.test_helpers.schedule.delete.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule/w+, respond with HTTP 200

`api.reports.v1.test_helpers.schedule.delete.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule/w+, respond with HTTP 401

## api.reports.v1.test_helpers.schedule.generate_from_schedule module

`api.reports.v1.test_helpers.schedule.generate_from_schedule.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule/w+/generate, respond with HTTP 403

`api.reports.v1.test_helpers.schedule.generate_from_schedule.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule/w+/generate, respond with HTTP 404

`api.reports.v1.test_helpers.schedule.generate_from_schedule.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule/w+/generate, respond with HTTP 200

`api.reports.v1.test_helpers.schedule.generate_from_schedule.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule/w+/generate, respond with HTTP 401

## api.reports.v1.test_helpers.schedule.get module

`api.reports.v1.test_helpers.schedule.get.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule/w+, respond with HTTP 403

`api.reports.v1.test_helpers.schedule.get.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule/w+, respond with HTTP 404

`api.reports.v1.test_helpers.schedule.get.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule/w+, respond with HTTP 200

`api.reports.v1.test_helpers.schedule.get.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule/w+, respond with HTTP 401

## api.reports.v1.test_helpers.schedule.get_search module

`api.reports.v1.test_helpers.schedule.get_search.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule, respond with HTTP 403

`api.reports.v1.test_helpers.schedule.get_search.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule, respond with HTTP 404

`api.reports.v1.test_helpers.schedule.get_search.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule, respond with HTTP 200

`api.reports.v1.test_helpers.schedule.get_search.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule, respond with HTTP 401

## api.reports.v1.test_helpers.schedule.search module

`api.reports.v1.test_helpers.schedule.search.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule/search, respond with HTTP 403

`api.reports.v1.test_helpers.schedule.search.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule/search, respond with HTTP 404

`api.reports.v1.test_helpers.schedule.search.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule/search, respond with HTTP 200

`api.reports.v1.test_helpers.schedule.search.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/schedule/search, respond with HTTP 401

## Module contents